#[non_exhaustive]
pub enum Request<'a> { SetSerial { serial: u32, seat: WlSeat, }, SetAppId { app_id: String, }, SetSurface { surface: WlSurface, }, Commit, Destroy, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SetSerial

specifies the seat and serial of the activating event

Provides information about the seat and serial event that requested the token.

The serial can come from an input or focus event. For instance, if a click triggers the launch of a third-party client, the launcher client should send a set_serial request with the serial and seat from the wl_pointer.button event.

Some compositors might refuse to activate toplevels when the token doesn’t have a valid and recent enough event serial.

Must be sent before commit. This information is optional.

Fields

serial: u32

the serial of the event that triggered the activation

seat: WlSeat

the wl_seat of the event



SetAppId

specifies the application being activated

The requesting client can specify an app_id to associate the token being created with it.

Must be sent before commit. This information is optional.

Fields

app_id: String

the application id of the client being activated.



SetSurface

specifies the surface requesting activation

This request sets the surface requesting the activation. Note, this is different from the surface that will be activated.

Some compositors might refuse to activate toplevels when the token doesn’t have a requesting surface.

Must be sent before commit. This information is optional.

Fields

surface: WlSurface

the requesting surface



Commit

issues the token request

Requests an activation token based on the different parameters that have been offered through set_serial, set_surface and set_app_id.



Destroy

destroy the xdg_activation_token_v1 object

Notify the compositor that the xdg_activation_token_v1 object will no longer be used. The received token stays valid.

This is a destructor, once sent this object cannot be used any longer.

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message